Documentation
¶
Overview ¶
Package v1alpha1 contains API Schema definitions for the pipelines v1alpha1 API group +kubebuilder:object:generate=true +groupName=pipelines.openshift.io
Index ¶
Constants ¶
This section is empty.
Variables ¶
var ( // GroupVersion is group version used to register these objects GroupVersion = schema.GroupVersion{Group: "pipelines.openshift.io", Version: "v1alpha1"} // SchemeBuilder is used to add go types to the GroupVersionKind scheme SchemeBuilder = &scheme.Builder{GroupVersion: GroupVersion} // AddToScheme adds the types in this group-version to the given scheme. AddToScheme = SchemeBuilder.AddToScheme )
Functions ¶
This section is empty.
Types ¶
type BackendStruct ¶ added in v1.20.0
type BackendStruct struct {
// Resources defines the resource requests and limits for the backend service
Resources *corev1.ResourceRequirements `json:"resources,omitempty"`
}
BackendStruct defines the resource configuration for the Backend components
func (*BackendStruct) DeepCopy ¶ added in v1.20.0
func (in *BackendStruct) DeepCopy() *BackendStruct
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new BackendStruct.
func (*BackendStruct) DeepCopyInto ¶ added in v1.20.0
func (in *BackendStruct) DeepCopyInto(out *BackendStruct)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type ConsolePluginStruct ¶ added in v1.20.0
type ConsolePluginStruct struct {
// Backend defines the resource requests and limits for the backend service
Backend *BackendStruct `json:"backend,omitempty"`
// GitopsPlugin defines the resource requests and limits for the gitops plugin service
GitopsPlugin *GitopsPluginStruct `json:"gitopsPlugin,omitempty"`
}
ConsolePluginStruct defines the resource configuration for the Console Plugin components
func (*ConsolePluginStruct) DeepCopy ¶ added in v1.20.0
func (in *ConsolePluginStruct) DeepCopy() *ConsolePluginStruct
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ConsolePluginStruct.
func (*ConsolePluginStruct) DeepCopyInto ¶ added in v1.20.0
func (in *ConsolePluginStruct) DeepCopyInto(out *ConsolePluginStruct)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type GitopsPluginStruct ¶ added in v1.20.0
type GitopsPluginStruct struct {
// Resources defines the resource requests and limits for the gitops plugin service
Resources *corev1.ResourceRequirements `json:"resources,omitempty"`
}
GitopsPluginStruct defines the resource configuration for the Gitops Plugin components
func (*GitopsPluginStruct) DeepCopy ¶ added in v1.20.0
func (in *GitopsPluginStruct) DeepCopy() *GitopsPluginStruct
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new GitopsPluginStruct.
func (*GitopsPluginStruct) DeepCopyInto ¶ added in v1.20.0
func (in *GitopsPluginStruct) DeepCopyInto(out *GitopsPluginStruct)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type GitopsService ¶
type GitopsService struct {
metav1.TypeMeta `json:",inline"`
metav1.ObjectMeta `json:"metadata,omitempty"`
Spec GitopsServiceSpec `json:"spec,omitempty"`
Status GitopsServiceStatus `json:"status,omitempty"`
}
GitopsService is the Schema for the gitopsservices API
func (*GitopsService) DeepCopy ¶
func (in *GitopsService) DeepCopy() *GitopsService
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new GitopsService.
func (*GitopsService) DeepCopyInto ¶
func (in *GitopsService) DeepCopyInto(out *GitopsService)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*GitopsService) DeepCopyObject ¶
func (in *GitopsService) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type GitopsServiceList ¶
type GitopsServiceList struct {
metav1.TypeMeta `json:",inline"`
metav1.ListMeta `json:"metadata,omitempty"`
Items []GitopsService `json:"items"`
}
GitopsServiceList contains a list of GitopsService
func (*GitopsServiceList) DeepCopy ¶
func (in *GitopsServiceList) DeepCopy() *GitopsServiceList
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new GitopsServiceList.
func (*GitopsServiceList) DeepCopyInto ¶
func (in *GitopsServiceList) DeepCopyInto(out *GitopsServiceList)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*GitopsServiceList) DeepCopyObject ¶
func (in *GitopsServiceList) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type GitopsServiceSpec ¶
type GitopsServiceSpec struct {
// InfraNodeEnabled will add infra NodeSelector to all the default workloads of gitops operator
RunOnInfra bool `json:"runOnInfra,omitempty"`
// Tolerations allow the default workloads to schedule onto nodes with matching taints
Tolerations []corev1.Toleration `json:"tolerations,omitempty"`
// NodeSelector is a map of key value pairs used for node selection in the default workloads
NodeSelector map[string]string `json:"nodeSelector,omitempty"`
// ConsolePlugin defines the Resource configuration for the Console Plugin components
ConsolePlugin *ConsolePluginStruct `json:"consolePlugin,omitempty"`
// ImagePullPolicy defines the image pull policy for GitOps workloads
// +kubebuilder:validation:Enum=Always;IfNotPresent;Never
ImagePullPolicy corev1.PullPolicy `json:"imagePullPolicy,omitempty"`
}
GitopsServiceSpec defines the desired state of GitopsService
func (*GitopsServiceSpec) DeepCopy ¶
func (in *GitopsServiceSpec) DeepCopy() *GitopsServiceSpec
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new GitopsServiceSpec.
func (*GitopsServiceSpec) DeepCopyInto ¶
func (in *GitopsServiceSpec) DeepCopyInto(out *GitopsServiceSpec)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type GitopsServiceStatus ¶
type GitopsServiceStatus struct {
}
GitopsServiceStatus defines the observed state of GitopsService
func (*GitopsServiceStatus) DeepCopy ¶
func (in *GitopsServiceStatus) DeepCopy() *GitopsServiceStatus
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new GitopsServiceStatus.
func (*GitopsServiceStatus) DeepCopyInto ¶
func (in *GitopsServiceStatus) DeepCopyInto(out *GitopsServiceStatus)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.